| Title: | Boosting your R packages' citations |
|---|---|
| Description: | Although used a core of scientific endeavors, citations of scientific software are often overlooked. This package provides tools to boost citation of R packages, making it easier for users to cite the software they use in their research. |
| Authors: | George Vega Yon [aut, cre] (ORCID: <https://orcid.org/0000-0002-3171-0844>), Centers for Disease Control and Prevention [fnd] (Award number 1U01CK000585; 75D30121F00003) |
| Maintainer: | George Vega Yon <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.9000 |
| Built: | 2026-05-18 07:47:57 UTC |
| Source: | https://github.com/UofUEpiBio/citer |
Set up the citation function on loading the package
citer_on_load(path = ".")citer_on_load(path = ".")
path |
The path to the package directory. Defaults to the current working directory. |